@@ -90,7 +90,7 @@ from( default_email )
 --
 -- Specify the outgoing mail binary.
 --
--- Prefer /usr/sbin/sendmail, but use /usr/lib/sendmail if that exists
+-- Prefer /usr/lib/sendmail, but use /usr/sbin/sendmail if that exists
 --
 if ( executable( "/usr/sbin/sendmail" ) ) then
    sendmail_path( "/usr/sbin/sendmail -t" )
@@ -227,6 +227,25 @@ maildir_highlight_mode('bold standout')
 --
 
 
+--
+-- When viewing a message the display will consist of:
+--
+--  The message headers.
+--  The list of attachments.
+--  The body of the message.
+--
+-- Due to recent changes in the way that attachments are viewed
+-- the list of attachments will consist of both external and inline
+-- attachments.
+--
+-- Set this value to true to disable the former:
+--
+-- view_inline_attachments = false
+--
+-- See also `view_attachments`
+--
+
+
 --
 -- This function will invoke offlineimap, if it is installed
 -- and configured for the current user.
@@ -261,6 +280,28 @@ function on_start()
 end
 
 
+--
+-- When there is an error in an invoked Lua function this method
+-- will be called.  This is true regardless of whether the error
+-- came from the lua-prompt, or a function in an initialization file.
+--
+-- Here we display the error to the user, but only in debug-builds.
+--
+-- This is a trade-off, we don't want to spoil the user-experience of
+-- a new user by showing too many errors, and somebody who is suspicious
+-- of their function can remove the debug-check.
+--
+-- NOTE:  DEBUG is a special defined variable, just like VERSION:
+--
+--        http://lumail.org/lua/DEBUG.html
+--
+function on_error( text )
+   if ( DEBUG == true ) then
+      msg( text )
+   end
+end
+
+
 --
 -- This function is called when a folder is added/removed/toggled
 -- within the selected set.
@@ -751,7 +792,7 @@ end
 --
 -- Should we wrap lines when showing a message?
 --
-function toggle_wrap_lines ()
+function toggle_line_wrapping ()
     if wrap_lines == nil then
         wrap_lines = true
     elseif wrap_lines == true then
@@ -761,6 +802,20 @@ function toggle_wrap_lines ()
     end
 end
 
+--
+-- Should we show attachments when displaying a message?
+--
+-- See also `view_inline_attachments`.
+--
+function toggle_show_attachments ()
+   if show_attachments == nil then
+        show_attachments = false
+    elseif show_attachments == true then
+        show_attachments = false
+    elseif show_attachments == false then
+        show_attachments = true
+    end
+end
 
 
 
@@ -1135,8 +1190,11 @@ keymap['maildir']['Enter'] = 'open_folder()'
 --
 --
 
--- wrap linese
-keymap['message']['w'] = 'toggle_wrap_lines()'
+-- Toggle the wrapping of long lines in headers/message-bodies.
+keymap['message']['w'] = 'toggle_line_wrapping()'
+
+-- Toggle the display of attachments in the message-display
+keymap['message']['A'] = 'toggle_show_attachments()'
 
 -- Actions
 keymap['message']['d'] = 'delete()'
@@ -1223,4 +1281,43 @@ end
 --
 keymap['global']['p'] = "toggle_maildir_names()"
 
+--
+-- Don't show the spam folder or empty "incoming" folders
+--
+function filter_maildirs(maildir)
+    if maildir.name == "spam" then
+        return false
+    elseif maildir:matches_regexp('/home/foo/mail/incoming/') and
+           maildir.total_messages == 0 then
+        return false
+    end
+    -- Include all other folders
+    return true
+end
 
+--
+-- Example maildir list sorting by name rather than path.
+--
+--[[
+function sort_maildirs(maildirs)
+    table.sort(maildirs, function (a, b) return a.name < b.name end)
+    return maildirs
+end
+]]
+
+--
+-- Fun times.
+--
+function  show_attachment_one()
+   txt ={}
+   txt[0] = attachment(1)
+   show_text( txt )
+   global_mode( "text")
+end
+
+function sb()
+   jpg = attachment(3)
+   x = io.open("/tmp/x.jpg", "wb")
+   x:write( jpg )
+   x:close()
+end
\ No newline at end of file
